<?php

/**
 * @file
 * Provides comment count from the Disqus.com integration.
 */

$plugin = array(
  'title' => t('Disqus Comment Count'),
  'description' => t('Comment count from Disqus comments'),
  'single' => TRUE,
  'render callback' => 'disqus_comment_count_content_type_render',
  'required context' => new ctools_context_required(t('Node'), 'node'),
  'defaults' => array(),
  // The category will appear in the panel content selection screen.
  'category' => t('Disqus'),
  'edit form' => 'disqus_comment_count_form_edit_form',
);

/**
 * Run-time rendering of the body of the block.
 *
 * @param string $subtype
 * @param array $conf
 *   Configuration as done at admin time.
 * @param array $args
 * @param object $context
 *   The node context, holding the currently selected node.
 *
 * @return null|object
 *   An object with at least title and content members.
 */
function disqus_comment_count_content_type_render($subtype, array $conf, array $args, $context) {
  if (!isset($context->data->disqus)) {
    return;
  }
  $disqus_identifier = $context->data->disqus['identifier'];
  $disqus_url = $context->data->disqus['url'];
  $disqus_domain = $context->data->disqus['domain'];

  $block = new StdClass();
  $block->content = <<<EOF
  <a href="$disqus_url#disqus_thread" data-disqus-identifier="$disqus_identifier">Comments</a>
<script type="text/javascript">
  var disqus_shortname = '$disqus_domain';
  (function () {
    var s = document.createElement('script');
    s.async = true;
    s.type = 'text/javascript';
    s.src = 'https://' + disqus_shortname + '.disqus.com/count.js';
    (document.getElementsByTagName('HEAD')[0] || document.getElementsByTagName('BODY')[0]).appendChild(s);
  }());
</script>
EOF;

  return $block;
}

/**
 * Callback for the 'Edit form'.
 */
function disqus_comment_count_form_edit_form(array $form, array &$form_state) {
  return $form;
}
